Module blaxel.core.client.models.preview_spec
=============================================

Classes
-------

`PreviewSpec(custom_domain: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, expires: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, port: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, prefix_url: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, public: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, region: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, request_headers: blaxel.core.client.types.Unset | ForwardRef('PreviewSpecRequestHeaders') = <blaxel.core.client.types.Unset object>, response_headers: blaxel.core.client.types.Unset | ForwardRef('PreviewSpecResponseHeaders') = <blaxel.core.client.types.Unset object>, ttl: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, url: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Preview of a Resource
    
    Attributes:
        custom_domain (Union[Unset, str]): Custom domain bound to this preview
        expires (Union[Unset, str]): The expiration date for the preview in ISO 8601 format - 2024-12-31T23:59:59Z
        port (Union[Unset, int]): Port of the preview
        prefix_url (Union[Unset, str]): Prefix URL
        public (Union[Unset, bool]): Whether the preview is public
        region (Union[Unset, str]): Region where the preview is deployed, this is readonly
        request_headers (Union[Unset, PreviewSpecRequestHeaders]): Those headers will be set in all requests to your
            preview. This is especially useful to set the Authorization header.
        response_headers (Union[Unset, PreviewSpecResponseHeaders]): Those headers will be set in all responses of your
            preview. This is especially useful to set the CORS headers.
        ttl (Union[Unset, str]): Time to live for the preview (e.g., "1h", "24h", "7d"). After this duration, the
            preview will be automatically deleted.
        url (Union[Unset, str]): URL of the preview
    
    Method generated by attrs for class PreviewSpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `custom_domain`
    :

    `expires`
    :

    `port`
    :

    `prefix_url`
    :

    `public`
    :

    `region`
    :

    `request_headers`
    :

    `response_headers`
    :

    `ttl`
    :

    `url`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :